@@ -18,8 +18,11 @@ class ConfigurationModule : public KCModule
     Q_OBJECT
 
 public:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    ConfigurationModule(QObject *parent, const KPluginMetaData &metaData);
+#else
     ConfigurationModule(QWidget *parent, const QVariantList &args);
-
+#endif
 public Q_SLOTS:
 
     void defaults() override;
